@@ -16,7 +16,7 @@ use Import::Into;
 use Data::OptList;
 use Module::Runtime 'use_module';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 binmode STDERR, ":encoding(utf8)";
 our $LOG_VERBOSE = 1;
@@ -72,7 +72,7 @@ sub import {
 				Moose->import({into=>$caller});
 				MooseX::StrictConstructor->import({into=>$caller});
 				MooseX::UndefTolerant->import({into=>$caller});
-				My::Types->import({into=>$caller});
+				App::SimulateReads::Types->import({into=>$caller});
 				after_runtime {
 					$caller->meta->make_immutable;
 				}
@@ -81,7 +81,7 @@ sub import {
 				require Moose::Role;
 				require App::SimulateReads::Types;
 				Moose::Role->import({into=>$caller});
-				My::Types->import({into=>$caller});
+				App::SimulateReads::Types->import({into=>$caller});
 			}
 			when ('test') {
 				use_module('Test::Most')->import::into($caller);
@@ -133,7 +133,7 @@ App::SimulateReads::Base - Policy and base module to App::SimulateReads project.
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
