@@ -6,13 +6,15 @@ use App::SimulateReads::Read::SingleEnd;
 
 extends 'App::SimulateReads::Fastq';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
-#-------------------------------------------------------------------------------
-#  Moose attributes
-#-------------------------------------------------------------------------------
-has 'sequencing_error' => (is => 'ro', isa => 'My:NumHS', required => 1);
-has '_read'            => (
+has 'sequencing_error' => (
+	is         => 'ro',
+	isa        => 'My:NumHS',
+	required   => 1
+);
+
+has '_read' => (
 	is         => 'ro',
 	isa        => 'App::SimulateReads::Read::SingleEnd',
 	builder    => '_build_read',
@@ -20,34 +22,20 @@ has '_read'            => (
 	handles    => [qw{ gen_read }]
 );
 
-#===  CLASS METHOD  ============================================================
-#        CLASS: Fastq::SingleEnd
-#       METHOD: _build_read (BUILDER)
-#   PARAMETERS: Void
-#      RETURNS: Read::SingleEnd obj
-#  DESCRIPTION: Build Read::SingleEnd object
-#       THROWS: no exceptions
-#     COMMENTS: none
-#     SEE ALSO: n/a
-#===============================================================================
+sub BUILD {
+	my $self = shift;
+	## Just to ensure that the lazy attributes are built before &new returns
+	$self->_read;
+}
+
 sub _build_read {
 	my $self = shift;
 	App::SimulateReads::Read::SingleEnd->new(
 		sequencing_error => $self->sequencing_error,
 		read_size        => $self->read_size
 	);
-} ## --- end sub _build_read
+}
 
-#===  CLASS METHOD  ============================================================
-#        CLASS: Fastq::SingleEnd
-#       METHOD: fastq
-#   PARAMETERS: $id Str, $seq_name Str, $seq_ref Ref Str, $seq_size Int > 0, $is_leader Bool
-#      RETURNS: sprint_fastq Ref Str
-#  DESCRIPTION: Consumes sprint_fastq parent template to generate a single-end fastq entry
-#       THROWS: no exceptions
-#     COMMENTS: none
-#     SEE ALSO: n/a
-#===============================================================================
 sub sprint_fastq {
 	my ($self, $id, $seq_name, $seq_ref, $seq_size, $is_leader) = @_;
 
@@ -60,7 +48,7 @@ sub sprint_fastq {
 	my $header = "$id simulation_read length=" . $self->read_size . " position=$seq_pos";
 
 	return $self->fastq_template(\$header, $read_ref);
-} ## --- end sub sprint_fastq
+}
 
 __END__
 
@@ -74,7 +62,7 @@ App::SimulateReads::Fastq::SingleEnd - App::SimulateReads::Fastq subclass for si
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
