@@ -10,7 +10,7 @@ use Parallel::ForkManager;
 
 with qw/App::SimulateReads::Role::WeightedRaffle App::SimulateReads::Role::IO/;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 #-------------------------------------------------------------------------------
 #  Moose attributes
@@ -129,24 +129,29 @@ sub _build_fasta {
 	my $self = shift;
 	log_msg ":: Indexing fasta file '" . $self->fasta_file . "' ...";
 	my $indexed_fasta = $self->index_fasta($self->fasta_file);
-	croak "Error parsing " . $self->fasta_file . ". Maybe the file is empty\n"
-		unless %$indexed_fasta;
+
+	unless (%$indexed_fasta) {
+		croak sprintf "Error parsing '%s'. Maybe the file is empty\n" => $self->fasta_file;
+	}
 
 	# Validate genome about the read size required
-	my $err;
 	for my $id (keys %$indexed_fasta) {
 		my $index_size = $indexed_fasta->{$id}{size};
 		given (ref $self->fastq) {
 			when ('App::SimulateReads::Fastq::SingleEnd') {
 				my $read_size = $self->fastq->read_size;
 				if ($index_size < $read_size) {
-					$err .= "seqid sequence length (>$id => $index_size) lesser than required read size ($read_size)\n";
+					log_msg ":: seqid sequence length (>$id => $index_size) lesser than required read size ($read_size)\n" .
+						"  -> I'm going to include '>$id' in the blacklist\n";
+					delete $indexed_fasta->{$id};
 				}
 			}
 			when ('App::SimulateReads::Fastq::PairedEnd') {
 				my $fragment_mean = $self->fastq->fragment_mean;
 				if ($index_size < $fragment_mean) {
-					$err .= "seqid sequence length (>$id => $index_size) lesser than required fragment mean ($fragment_mean)\n";
+					log_msg ":: seqid sequence length (>$id => $index_size) lesser than required fragment mean ($fragment_mean)\n" .
+						"  -> I'm going to include '>$id' in the blacklist\n";
+					delete $indexed_fasta->{$id};
 				}
 			}
 			default {
@@ -155,7 +160,10 @@ sub _build_fasta {
 		}
 	}
 	
-	croak "Error parsing '" . $self->fasta_file . "':\n$err" if defined $err;
+	unless (%$indexed_fasta) {
+		croak sprintf "Fasta file '%s' has no valid entry\n" => $self->fasta_file;
+	}
+
 	return $indexed_fasta;
 } ## --- end sub _build_fasta
 
@@ -463,7 +471,7 @@ App::SimulateReads::Simulator - Class responsible to make the simulation
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
